AdjustAppStoreSubscription class

Constructors

AdjustAppStoreSubscription(String _price, String _currency, String _transactionId)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesRegion ↔ String?
getter/setter pair
toMap → Map<String, String?>
no setter
transactionDate ↔ String?
getter/setter pair

Methods

addCallbackParameter(String key, String value) → void
addPartnerParameter(String key, String value) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited